==> react-json-view-preview-1.0.0.tgz: package/esm/comps/ellipsis.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["style", "render", "count", "level"];
import { ValueView } from '../value';
import './ellipsis.css';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
function getType(value) {
  // Check for null explicitly as typeof null === 'object'
  if (value === null) {
    return 'null';
  }

  // Check for Array
  if (Array.isArray(value)) {
    return 'Array';
  }

  // Check for special object types: Set and Map
  if (value instanceof Set) {
    return 'Set';
  }
  if (value instanceof Map) {
    return 'Map';
  }

  // Check for object (this is placed after the checks for Array, Set, and Map)
  if (typeof value === 'object') {
    return 'Object';
  }

  // Covers undefined and other primitive types
  return typeof value;
}
function getSubValue(value) {
  switch (getType(value)) {
    case 'Array':
      return '[...]';
    case 'Object':
      return '{...}';
    default:
      return /*#__PURE__*/_jsx(ValueView, {
        value: value,
        displayDataTypes: false,
        displayObjectSize: false,
        isSet: false,
        enableClipboard: false,
        indentWidth: 4
      });
  }
}
function getEllipsisStr(obj) {
  var result = '';
  if (typeof obj === 'object' && !Array.isArray(obj)) {
    console.log('strArr', Object.entries(obj));
    result = /*#__PURE__*/_jsx("span", {
      style: {
        margin: '0 2px'
      },
      children: Object.entries(obj).map((_ref, index) => {
        var [key, value] = _ref;
        return /*#__PURE__*/_jsxs("span", {
          children: [/*#__PURE__*/_jsxs("span", {
            className: "w-rjv-object-key",
            style: {
              opacity: 0.4
            },
            children: [key, ":"]
          }), /*#__PURE__*/_jsx("span", {
            className: "w-rjv-ellipsis-value",
            children: getSubValue(value)
          }), index !== Object.entries(obj).length - 1 ? ', ' : '']
        });
      })
    });
  } else if (Array.isArray(obj)) {
    result = /*#__PURE__*/_jsx("span", {
      children: obj.map((item, index) => {
        return /*#__PURE__*/_jsxs("span", {
          className: "w-rjv-ellipsis-array-wrapper",
          children: [/*#__PURE__*/_jsx("span", {
            className: "w-rjv-ellipsis-value",
            children: getSubValue(item)
          }), index !== obj.length - 1 ? ', ' : '']
        });
      })
    });
  }
  console.log('result', result);
  return result;
}
export var Ellipsis = _ref2 => {
  var {
      style,
      render,
      count,
      level
    } = _ref2,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded);
  var styl = _extends({
    cursor: 'pointer'
  }, style);
  var className = "w-rjv-ellipsis " + (props.className || '');
  if (render) return render(_extends({
    style: styl,
    count,
    level
  }, props, {
    className
  }));
  console.log('valueData', props.valueData);
  return /*#__PURE__*/_jsx("span", _extends({
    className: className,
    style: styl
  }, props, {
    children: getEllipsisStr(props.valueData)
  }));
};
Ellipsis.displayName = 'JVR.Ellipsis';

==> react-json-view-preview-1.0.2.tgz: package/esm/comps/ellipsis.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["style", "render", "count", "level"];
import { ValueView } from '../value';
import './ellipsis.css';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
function getType(value) {
  // Check for null explicitly as typeof null === 'object'
  if (value === null) {
    return 'null';
  }

  // Check for Array
  if (Array.isArray(value)) {
    return 'Array';
  }

  // Check for special object types: Set and Map
  if (value instanceof Set) {
    return 'Set';
  }
  if (value instanceof Map) {
    return 'Map';
  }

  // Check for object (this is placed after the checks for Array, Set, and Map)
  if (typeof value === 'object') {
    return 'Object';
  }

  // Covers undefined and other primitive types
  return typeof value;
}
function getSubValue(value) {
  switch (getType(value)) {
    case 'Array':
      return '[...]';
    case 'Object':
      return '{...}';
    default:
      return /*#__PURE__*/_jsx(ValueView, {
        value: value,
        displayDataTypes: false,
        displayObjectSize: false,
        isSet: false,
        enableClipboard: false,
        indentWidth: 4
      });
  }
}
function getEllipsisStr(obj) {
  var result = '';
  if (typeof obj === 'object' && !Array.isArray(obj)) {
    console.log('strArr', Object.entries(obj));
    result = /*#__PURE__*/_jsx("span", {
      style: {
        margin: '0 2px'
      },
      className: "w-rjv-ellipsis-wrapper",
      children: Object.entries(obj).map((_ref, index) => {
        var [key, value] = _ref;
        return /*#__PURE__*/_jsxs("span", {
          children: [/*#__PURE__*/_jsxs("span", {
            className: "w-rjv-object-key",
            style: {
              opacity: 0.4
            },
            children: [key, ":"]
          }), /*#__PURE__*/_jsx("span", {
            className: "w-rjv-ellipsis-value",
            children: getSubValue(value)
          }), index !== Object.entries(obj).length - 1 ? ', ' : '']
        });
      })
    });
  } else if (Array.isArray(obj)) {
    result = /*#__PURE__*/_jsx("span", {
      children: obj.map((item, index) => {
        return /*#__PURE__*/_jsxs("span", {
          className: "w-rjv-ellipsis-wrapper w-rjv-ellipsis-array-wrapper",
          children: [/*#__PURE__*/_jsx("span", {
            className: "w-rjv-ellipsis-value",
            children: getSubValue(item)
          }), index !== obj.length - 1 ? ', ' : '']
        });
      })
    });
  }
  console.log('result', result);
  return result;
}
export var Ellipsis = _ref2 => {
  var {
      style,
      render,
      count,
      level
    } = _ref2,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded);
  var styl = _extends({
    cursor: 'pointer'
  }, style);
  var className = "w-rjv-ellipsis " + (props.className || '');
  if (render) return render(_extends({
    style: styl,
    count,
    level
  }, props, {
    className
  }));
  console.log('valueData', props.valueData);
  return /*#__PURE__*/_jsx("span", _extends({
    className: className,
    style: styl
  }, props, {
    children: getEllipsisStr(props.valueData)
  }));
};
Ellipsis.displayName = 'JVR.Ellipsis';
